@@ -274,60 +274,22 @@ BiCopPar2Tau <- function(family, par, par2 = 0, obj = NULL, check.pars = TRUE) {
 }
 
 
-
-# frankParGrid <- seq(-101, 101, l = 100)
-frankParGrid <- c(-101, -98.959595959596, -96.9191919191919, -94.8787878787879,
-                  -92.8383838383838, -90.7979797979798, -88.7575757575758, -86.7171717171717,
-                  -84.6767676767677, -82.6363636363636, -80.5959595959596, -78.5555555555556,
-                  -76.5151515151515, -74.4747474747475, -72.4343434343434, -70.3939393939394,
-                  -68.3535353535354, -66.3131313131313, -64.2727272727273, -62.2323232323232,
-                  -60.1919191919192, -58.1515151515152, -56.1111111111111, -54.0707070707071,
-                  -52.030303030303, -49.989898989899, -47.949494949495, -45.9090909090909,
-                  -43.8686868686869, -41.8282828282828, -39.7878787878788, -37.7474747474748,
-                  -35.7070707070707, -33.6666666666667, -31.6262626262626, -29.5858585858586,
-                  -27.5454545454545, -25.5050505050505, -23.4646464646465, -21.4242424242424,
-                  -19.3838383838384, -17.3434343434344, -15.3030303030303, -13.2626262626263,
-                  -11.2222222222222, -9.18181818181819, -7.14141414141415, -5.1010101010101,
-                  -3.06060606060606, -1.02020202020203, 1.02020202020201, 3.06060606060605,
-                  5.10101010101009, 7.14141414141413, 9.18181818181817, 11.2222222222222,
-                  13.2626262626263, 15.3030303030303, 17.3434343434343, 19.3838383838384,
-                  21.4242424242424, 23.4646464646464, 25.5050505050505, 27.5454545454545,
-                  29.5858585858586, 31.6262626262626, 33.6666666666667, 35.7070707070707,
-                  37.7474747474747, 39.7878787878788, 41.8282828282828, 43.8686868686869,
-                  45.9090909090909, 47.9494949494949, 49.989898989899, 52.030303030303,
-                  54.070707070707, 56.1111111111111, 58.1515151515151, 60.1919191919192,
-                  62.2323232323232, 64.2727272727273, 66.3131313131313, 68.3535353535353,
-                  70.3939393939394, 72.4343434343434, 74.4747474747475, 76.5151515151515,
-                  78.5555555555555, 80.5959595959596, 82.6363636363636, 84.6767676767677,
-                  86.7171717171717, 88.7575757575758, 90.7979797979798, 92.8383838383838,
-                  94.8787878787879, 96.9191919191919, 98.9595959595959, 101)
+frankParGrid <- c(-10^(5:2), seq(-36, 36, l = 100), 10^(2:5))
 # frankTauVals <- 1 - 4/frankParGrid + 4/frankParGrid * copula::debye1(frankParGrid)
-frankTauVals <- c(-0.961041048550867, -0.960251344564296, -0.95942897342536,
-                 -0.958571866033333, -0.957677774843704, -0.956744254215267, -0.955768638102463,
-                 -0.954748014665184, -0.953679197287614, -0.952558691399602, -0.951382656374172,
-                 -0.950146861627529, -0.948846635866317, -0.947476808201624, -0.946031639568512,
-                 -0.944504742537972, -0.942888987164558, -0.941176389950323, -0.93935798228736,
-                 -0.937423653818046, -0.935361964957013, -0.933159921260012, -0.930802700275106,
-                 -0.928273318793382, -0.925552224778557, -0.922616793339209, -0.919440699396042,
-                 -0.91599313043174, -0.912237789768897, -0.908131622511068, -0.903623170019409,
-                 -0.898650420568253, -0.893137967278655, -0.886993199334039, -0.880101121990825,
-                 -0.872317196660623, -0.863457265500544, -0.853283089132126, -0.84148112450054,
-                 -0.827630609937665, -0.811154246217934, -0.791239672221123, -0.766710388198721,
-                 -0.73580674780385, -0.69580488947752, -0.642352809081713, -0.568396118348008,
-                 -0.462982587231658, -0.312511738501557, -0.112196429394003, 0.112196429394,
-                 0.312511738501556, 0.462982587231657, 0.568396118348008, 0.642352809081712,
-                 0.695804889477519, 0.73580674780385, 0.76671038819872, 0.791239672221123,
-                 0.811154246217934, 0.827630609937665, 0.84148112450054, 0.853283089132126,
-                 0.863457265500544, 0.872317196660623, 0.880101121990825, 0.886993199334039,
-                 0.893137967278656, 0.898650420568252, 0.903623170019409, 0.908131622511068,
-                 0.912237789768897, 0.91599313043174, 0.919440699396043, 0.92261679333921,
-                 0.925552224778557, 0.928273318793382, 0.930802700275106, 0.933159921260012,
-                 0.935361964957013, 0.937423653818045, 0.93935798228736, 0.941176389950323,
-                 0.942888987164558, 0.944504742537972, 0.946031639568512, 0.947476808201624,
-                 0.948846635866317, 0.950146861627529, 0.951382656374172, 0.952558691399602,
-                 0.953679197287614, 0.954748014665184, 0.955768638102463, 0.956744254215266,
-                 0.957677774843704, 0.958571866033333, 0.95942897342536, 0.960251344564296,
-                 0.961041048550867)
+frankTauVals <- c(-0.99996000, -0.99960007, -0.99600658, -0.96065797, -0.89396585, -0.89188641, -0.88972402, -0.88747361,
+                  -0.88512973, -0.88268644, -0.88013730, -0.87747533, -0.87469288, -0.87178163, -0.86873246, -0.86553538,
+                  -0.86217942, -0.85865252, -0.85494133, -0.85103114, -0.84690560, -0.84254657, -0.83793380, -0.83304468,
+                  -0.82785385, -0.82233280, -0.81644934, -0.81016705, -0.80344454, -0.79623459, -0.78848313, -0.78012801,
+                  -0.77109744, -0.76130821, -0.75066334, -0.73904940, -0.72633308, -0.71235706, -0.69693500, -0.67984550,
+                  -0.66082501, -0.63955977, -0.61567712, -0.58873731, -0.55822774, -0.52356346, -0.48410024, -0.43916961,
+                  -0.38814802, -0.33057147, -0.26629772, -0.19569472, -0.11979813, -0.04035073,  0.04035073,  0.11979813,
+                  0.19569472,  0.26629772,  0.33057147,  0.38814802,  0.43916961,  0.48410024, 0.52356346,  0.55822774,
+                  0.58873731,  0.61567712,  0.63955977,  0.66082501,  0.67984550,  0.69693500,  0.71235706,  0.72633308,
+                  0.73904940,  0.75066334,  0.76130821,  0.77109744,  0.78012801,  0.78848313,  0.79623459,  0.80344454,
+                  0.81016705,  0.81644934,  0.82233280,  0.82785385,  0.83304468,  0.83793380,  0.84254657,  0.84690560,
+                  0.85103114,  0.85494133,  0.85865252,  0.86217942,  0.86553538,  0.86873246,  0.87178163,  0.87469288,
+                  0.87747533,  0.88013730,  0.88268644,  0.88512973,  0.88747361,  0.88972402,  0.89188641,  0.89396585,
+                  0.96065797,  0.99600658,  0.99960007,  0.99996000)
 frankTau <- function(par) {
     approx(x = frankParGrid, y = frankTauVals, xout = par)$y
 }
